@@ -1,7 +1,5 @@
 package MojoX::Routes::AsGraph;
-our $VERSION = '0.04';
-
-
+$MojoX::Routes::AsGraph::VERSION = '0.05';
 use warnings;
 use strict;
 use Graph::Easy;
@@ -32,7 +30,7 @@ sub _new_node {
     $ctrl_actn = $controller || '';
     $ctrl_actn .= "->$action" if $action;
 
-    $pattern    = $pattern->pattern;
+    $pattern    = $pattern->unparsed;
   }
 
   ### Create node
@@ -73,7 +71,7 @@ MojoX::Routes::AsGraph - Create a graph from a MojoX::Routes object
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -157,4 +155,4 @@ Use the #mojo channel at FreeNode.
 Copyright 2009 Pedro Melo.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
\ No newline at end of file
+under the same terms as Perl itself.
